@@ -19,6 +19,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+import gettext
+
+gettext.install("ibus-libpinyin")
 
 def get_version():
-    return "1.8.92"
+    return "1.11.0"
+
+def get_longname():
+    return _("Intelligent Pinyin")
